. /lib/rcscripts/sh/error.sh

DESTDIR=/usr/local/packages/VMD3
ADPPACKCFG=$DESTDIR/package.conf
PHC="parhandclient --nocgi"

if [ -r $ADPPACKCFG ]; then
	. $ADPPACKCFG || :
else
	error "Could not source (1) '$ADPPACKCFG'"
fi

LAPPNAME=${APPNAME%.*}
LOG="logger -t monolith[0] $LAPPNAME:"

_validate_op() {
	# $1 - operator to validate
	[ $# -eq 1 ] || error "_validate_op: wrong number of arguments!"

	case $1 in
		lt|le|eq|ne|ge|gt)
			;;
		*)
			return 1
			;;
	esac
}

_validate_vers() {
	# $1 - version number to validate
	[ $# -eq 1 ] || error "_validate_vers: wrong number of arguments!"

	case $1 in
		*[!0-9.]*|.*|*.|*..*)
			return 1
			;;
	esac
}

_nof_args() {
	# $1 - variable to put the result in
	# $2 - variable to calculate the number of digits parts separated by '.'
	[ $# -eq 2 ] || error "_nof_args: wrong number of arguments!"

	local IFS result=$1

	_validate_vers $2 ||
		error "_nof_args: invalid version number '$2'"

	IFS=.
	set -- $2
	eval $result=$#
}

_split_vers() {
	# $1 - array to put the result in
	# $2 - version number to split
	# $3 - number of digits to split the version number in
	[ $# -eq 3 ] || error "_split_vers: wrong number of arguments!"

	local IFS=. array=$1 version=$2 i=1 nbr=$3 tmp

	set -- $version

	while [ $i -le $nbr ]; do
		eval tmp=\$$i
		if [ "$tmp" ]; then
			eval $array$i=\$$i
		else
			eval $array$i=0
		fi
		i=$(($i + 1))
	done
}

_clean_arg() {
	# $1 - argument to clean
	[ "$1" ] && [ $# -eq 1 ] || error "_clean_arg: wrong number of arguments or empty argument!"

	local arg=$1

	eval $arg=\${$arg#\\\"}
	eval $arg=\${$arg%\\\"}
}

_compare_vers() {
	# $1 - version number one
	# $2 - operation to execute on the version numbers
	# $3 - version number to compare version number one with
	[ $# -eq 3 ] && [ "$1" ] && [ "$2" ] && [ "$3" ] ||
	error "_compare_vers: wrong number of arguments or empty argument(s)!"

	local version1=$1 op=$2 version2=$3 nbr i=1
	local nbr_count1 nbr_count2 number1 number2 res=0

	#removing double quotes from arguments
	_clean_arg version1
	_clean_arg version2
	_clean_arg op

	_validate_op $op || error "_compare_vers: invalid operator '$op'"

	_nof_args nbr_count1 $version1 ||
		error "_compare_vers: weird version arg1 '$version1' string"
	_nof_args nbr_count2 $version2 ||
		error "_compare_vers: weird version arg2 '$version2' string"

	nbr=$nbr_count1
	[ $nbr_count1 -gt $nbr_count2 ] || nbr=$nbr_count2

	_split_vers v1_nbr_ $version1 $nbr
	_split_vers v2_nbr_ $version2 $nbr

	while [ $i -le $nbr ] && [ $res -eq 0 ]; do
		eval number1=\$v1_nbr_$i
		eval number2=\$v2_nbr_$i
		case $op in
			le)
				if [ $number1 -lt $number2 ]; then
					break
				elif [ $number1 -eq $number2 ]; then
					:
				else
					res=1
				fi
        ;;
    esac
		i=$(($i + 1))
	done
	return $res
}

_rmapp() {
	[ $# -eq 1 ] && [ "$1" ] ||
		error "_rmapp: wrong number of arguments or empty argument(s)!"
	$LOG -p user.err -- " POSTINSTALLSCRIPT, Uninstalling application."
	dir=$(pwd)
	cd /usr/local/packages/VideoMotionDetection
	/usr/sbin/install-package.sh uninstall
	cd $dir
	exit 1
}

check_version() {
	if embdevversion=$($PHC get properties.EmbeddedDevelopment.Version 2>&1); then
		[ -z "$REQEMBDEVVERSION" ] && {
			$LOG -p user.err -- "  POSTINSTALLSCRIPT, Could not determine the REQEMBDEVVERSION for '$LAPPNAME'. Make sure it is set in package.conf."
			_rmapp $DESTDIR
		}
		_compare_vers $REQEMBDEVVERSION le $embdevversion || {
			$LOG -p user.err -- " POSTINSTALLSCRIPT, Invalid platform version $embdevversion < \"$REQEMBDEVVERSION\"."
			_rmapp $DESTDIR
		}
	else
		$LOG -p user.err -- " POSTINSTALLSCRIPT, Failed to check platform compatibility with application '$LAPPNAME'."
		_rmapp $DESTDIR
	fi
}

# comment: This script will be used as a post-install script for VMD.
# It will make sure that the required version of 
# Embedded Development Version is installed on the camera.
check_version

